@@ -1,20 +1,23 @@
 use crate::primes::LargeSafePrime;
-#[cfg(all(not(feature = "rug"), feature = "num-bigint"))]
+#[cfg(all(feature = "srp-default-math", not(feature = "srp-fast-math")))]
 use num_bigint::{BigInt, Sign};
-#[cfg(all(feature = "rug", not(feature = "num-bigint")))]
+#[cfg(feature = "srp-fast-math")]
 use rug::integer::Order;
-#[cfg(all(feature = "rug", not(feature = "num-bigint")))]
+#[cfg(feature = "srp-fast-math")]
 use rug::Integer as RugInt;
 use std::ops;
 
+#[cfg(not(any(feature = "srp-fast-math", feature = "srp-default-math")))]
+compile_error!("Either the 'srp-fast-math' feature or the 'srp-default-math' feature must be enabled.\n\n The features exclusively select an arbitrary integer library.\n Use 'srp-default-math' if you want no-dependency compilation, but slow execution speed. Use 'srp-fast-math' if you want exceptional execution speed but external dependencies.");
+
 pub(crate) struct Integer {
-    #[cfg(all(not(feature = "rug"), feature = "num-bigint"))]
+    #[cfg(all(feature = "srp-default-math", not(feature = "srp-fast-math")))]
     value: BigInt,
-    #[cfg(all(feature = "rug", not(feature = "num-bigint")))]
+    #[cfg(feature = "srp-fast-math")]
     value: RugInt,
 }
 
-#[cfg(all(not(feature = "rug"), feature = "num-bigint"))]
+#[cfg(all(feature = "srp-default-math", not(feature = "srp-fast-math")))]
 impl Integer {
     #[inline(always)]
     const fn from_bigint(bigint: BigInt) -> Self {
@@ -57,7 +60,7 @@ impl Integer {
     }
 }
 
-#[cfg(all(feature = "rug", not(feature = "num-bigint")))]
+#[cfg(feature = "srp-fast-math")]
 impl Integer {
     #[inline(always)]
     const fn from_bigint(bigint: RugInt) -> Self {
@@ -103,18 +106,17 @@ impl Integer {
         Self::from_bigint(RugInt::from_digits(&v, Order::LsfLe))
     }
 }
-#[cfg(all(not(feature = "rug"), feature = "num-bigint"))]
-impl From<u8> for Integer {
-    fn from(v: u8) -> Self {
-        Self::from_bigint(BigInt::from(v))
-    }
-}
 
-#[cfg(all(feature = "rug", not(feature = "num-bigint")))]
 impl From<u8> for Integer {
+    #[cfg(feature = "srp-fast-math")]
     fn from(v: u8) -> Self {
         Self::from_bigint(RugInt::from(v))
     }
+
+    #[cfg(all(not(feature = "srp-fast-math"), feature = "srp-default-math"))]
+    fn from(v: u8) -> Self {
+        Self::from_bigint(BigInt::from(v))
+    }
 }
 
 impl ops::Mul<Integer> for Integer {
