@@ -122,12 +122,13 @@ pub use encrypt::EncrypterHalf;
 use crate::error::MatchProofsError;
 use crate::key::{Proof, SessionKey};
 use crate::normalized_string::NormalizedString;
-use crate::srp_internal::calculate_world_server_proof;
 use crate::{PROOF_LENGTH, SESSION_KEY_LENGTH};
+use internal::calculate_world_server_proof;
 use rand::{thread_rng, RngCore};
 
 pub(crate) mod decrypt;
 pub(crate) mod encrypt;
+mod internal;
 pub(crate) mod traits;
 
 /// Decrypted values from a server.
@@ -359,6 +360,42 @@ mod test {
     use crate::SESSION_KEY_LENGTH;
     use std::convert::TryInto;
 
+    #[test]
+    fn verify_seed_proof() {
+        const FILE: &'static str = "tests/encryption/calculate_world_server_proof.txt";
+        let contents = read_to_string(FILE).unwrap();
+        for line in contents.lines() {
+            let mut line = line.split_whitespace();
+
+            let username = line.next().unwrap();
+            let session_key = SessionKey::from_be_hex_str(line.next().unwrap());
+            let server_seed = u32::from_le_bytes(
+                hex::decode(line.next().unwrap())
+                    .unwrap()
+                    .try_into()
+                    .unwrap(),
+            );
+            let client_seed = ProofSeed::from_specific_seed(u32::from_le_bytes(
+                hex::decode(line.next().unwrap())
+                    .unwrap()
+                    .try_into()
+                    .unwrap(),
+            ));
+            let expected: [u8; 20] = hex::decode(line.next().unwrap())
+                .unwrap()
+                .try_into()
+                .unwrap();
+
+            let (proof, _) = client_seed.into_proof_and_header_crypto(
+                &username.try_into().unwrap(),
+                *session_key.as_le(),
+                server_seed,
+            );
+
+            assert_eq!(expected, proof);
+        }
+    }
+
     #[test]
     fn verify_client_and_server_agree() {
         let session_key = [
