@@ -95,7 +95,7 @@ pub fn calculate_password_verifier(
     salt: &Salt,
     // Return an array instead of Verifier because this is never directly used to create a Verifier
 ) -> [u8; PASSWORD_VERIFIER_LENGTH as usize] {
-    let x = calculate_x(username, password, &salt).to_bigint();
+    let x = calculate_x(username, password, salt).to_bigint();
 
     let generator = Generator::default().to_bigint();
     let large_safe_prime = LargeSafePrime::default().to_bigint();
@@ -184,12 +184,7 @@ pub fn calculate_session_key(
 ) -> SessionKey {
     let u = &calculate_u(client_public_key, server_public_key);
     #[allow(non_snake_case)]
-    let S = calculate_S(
-        &client_public_key,
-        &password_verifier,
-        &u,
-        &server_private_key,
-    );
+    let S = calculate_S(client_public_key, password_verifier, u, server_private_key);
 
     calculate_interleaved(&S)
 }
@@ -262,24 +257,6 @@ pub fn calculate_reconnect_proof(
     Proof::from_le_bytes(s.into())
 }
 
-pub fn calculate_world_server_proof(
-    username: &NormalizedString,
-    session_key: &SessionKey,
-    server_seed: u32,
-    client_seed: u32,
-) -> Proof {
-    let server_proof: [u8; PROOF_LENGTH as usize] = Sha1::new()
-        .chain(&username.as_ref())
-        .chain(0_u32.to_le_bytes())
-        .chain(client_seed.to_le_bytes())
-        .chain(server_seed.to_le_bytes())
-        .chain(&session_key.as_le())
-        .finalize()
-        .into();
-
-    Proof::from_le_bytes(server_proof)
-}
-
 #[cfg(test)]
 mod test {
     use crate::primes::{
@@ -295,50 +272,10 @@ mod test {
         use crate::srp_internal::{
             calculate_S, calculate_client_proof, calculate_interleaved,
             calculate_password_verifier, calculate_reconnect_proof, calculate_server_proof,
-            calculate_server_public_key, calculate_session_key, calculate_u,
-            calculate_world_server_proof, calculate_x,
+            calculate_server_public_key, calculate_session_key, calculate_u, calculate_x,
         };
-        use std::convert::TryInto;
         use std::fs::read_to_string;
 
-        #[test]
-        fn verify_world_server_proof() {
-            const FILENAME: &str = "tests/srp6_internal/calculate_world_server_proof.txt";
-
-            let contents = read_to_string(FILENAME).unwrap();
-            for line in contents.lines() {
-                let mut line = line.split_whitespace();
-
-                let username = NormalizedString::new(line.next().unwrap()).unwrap();
-
-                let session_key = SessionKey::from_le_hex_str(line.next().unwrap());
-
-                let server_seed = u32::from_le_bytes(
-                    hex::decode(line.next().unwrap())
-                        .unwrap()
-                        .try_into()
-                        .unwrap(),
-                );
-                let client_seed = u32::from_le_bytes(
-                    hex::decode(line.next().unwrap())
-                        .unwrap()
-                        .try_into()
-                        .unwrap(),
-                );
-
-                let expected = Proof::from_le_hex_str(line.next().unwrap());
-
-                let result = calculate_world_server_proof(
-                    &NormalizedString::new(&username.to_string()).unwrap(),
-                    &session_key,
-                    server_seed,
-                    client_seed,
-                );
-
-                assert_eq!(result, expected);
-            }
-        }
-
         #[test]
         fn verify_reconnection_proof() {
             let contents =
